@@ -100,7 +100,7 @@ KWalletEditor::KWalletEditor(QWidget *parent, const QString &name)
     box->addWidget(_mapEditor);
 
     // load splitter size
-    KConfigGroup cg(KSharedConfig::openConfig(), "WalletEditor");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("WalletEditor"));
     QList<int> splitterSize = cg.readEntry("SplitterSize", QList<int>());
     if (splitterSize.size() != 2) {
         splitterSize.clear();
@@ -138,7 +138,7 @@ KWalletEditor::~KWalletEditor()
     Q_EMIT enableWalletActions(false);
     Q_EMIT enableContextFolderActions(false);
     // save splitter size
-    KConfigGroup cg(KSharedConfig::openConfig(), "WalletEditor");
+    KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("WalletEditor"));
     cg.writeEntry("SplitterSize", _splitter->sizes());
     cg.writeEntry("AlwaysShowContents", _alwaysShowContents);
     cg.sync();
@@ -421,20 +421,12 @@ void KWalletEditor::createFolder()
             }
 
             if (_entryList->existsFolder(n)) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 int rc = KMessageBox::questionTwoActions(this,
                                                          i18n("Sorry, that folder name is in use. Try again?"),
                                                          QString(),
                                                          KGuiItem(i18n("Try Again")),
                                                          KGuiItem(i18n("Do Not Try")));
-#else
-                int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that folder name is in use. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
-#endif
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 if (rc == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-                if (rc == KMessageBox::Yes) {
-#endif
                     continue;
                 }
                 n.clear();
@@ -492,13 +484,8 @@ void KWalletEditor::entrySelectionChanged(QTreeWidgetItem *item)
 {
     // do not forget to save changes
     if (_saveChanges->isEnabled() && _displayedItem && (_displayedItem != item)) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
         if (KMessageBox::ButtonCode::PrimaryAction
             == KMessageBox::questionTwoActions(this,
-#else
-        if (KMessageBox::Yes
-            == KMessageBox::questionYesNo(this,
-#endif
                                                i18n("The contents of the current item has changed.\nDo you want to save changes?"),
                                                {},
                                                KStandardGuiItem::save(),
@@ -799,20 +786,12 @@ void KWalletEditor::newEntry()
 
         // FIXME: prohibits the use of the subheadings
         if (fi->contains(n)) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             int rc = KMessageBox::questionTwoActions(this,
                                                      i18n("Sorry, that entry already exists. Try again?"),
                                                      QString(),
                                                      KGuiItem(i18n("Try Again")),
                                                      KGuiItem(i18n("Do Not Try")));
-#else
-            int rc = KMessageBox::questionYesNo(this, i18n("Sorry, that entry already exists. Try again?"), QString(), KGuiItem(i18n("Try Again")), KGuiItem(i18n("Do Not Try")));
-#endif
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (rc == KMessageBox::ButtonCode::PrimaryAction) {
-#else
-            if (rc == KMessageBox::Yes) {
-#endif
                 continue;
             }
             n.clear();
