@@ -17,13 +17,9 @@
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-#endif
     QApplication a(argc, argv);
     KCrash::initialize();
-    KLocalizedString::setApplicationDomain("kwalletmanager");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("kwalletmanager"));
 
     a.setWindowIcon(QIcon::fromTheme(QStringLiteral("kwalletmanager")));
 
@@ -34,7 +30,7 @@ int main(int argc, char **argv)
                  KAboutLicense::GPL,
                  i18n("Copyright ©2013–2017, KWallet Manager authors"),
                  QString(),
-                 QStringLiteral("https://utils.kde.org/projects/kwalletmanager/"));
+                 QStringLiteral("https://apps.kde.org/kwalletmanager5"));
 
     aboutData.addAuthor(i18n("Valentin Rusu"),
                         i18n("Maintainer, user interface refactoring"),
